==> haskell-libxml-0.1.1-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-libxml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 libxml
version:              0.1.1
visibility:           public
id:                   libxml-0.1.1-D25xQPVYnSdID5yTdz9QdH
key:                  libxml-0.1.1-D25xQPVYnSdID5yTdz9QdH
license:              BSD-3-Clause
copyright:            2006, Lemmih
maintainer:           Lemmih (lemmih@gmail.com)
author:               Lemmih (lemmih@gmail.com)
synopsis:             Binding to libxml2
description:
    Minimal binding to libxml2. Additional functions will be added when needed.

category:             XML
abi:                  23cba88eea2f27aa0ea28541696dff06
exposed:              True
exposed-modules:
    Text.XML.LibXML Text.XML.LibXML.Internals Text.XML.LibXML.Parser
    Text.XML.LibXML.Tree Text.XML.LibXML.Types

import-dirs:          /usr/lib/ghc-8.8.1/site-local/libxml-0.1.1
library-dirs:         /usr/lib/ghc-8.8.1/site-local/libxml-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/libxml-0.1.1
hs-libraries:         HSlibxml-0.1.1-D25xQPVYnSdID5yTdz9QdH
extra-libraries:      xml2
include-dirs:         /usr/include/libxml2
includes:             libxml/xmlIO.h libxml/xmlmemory.h
depends:              base-4.13.0.0 bytestring-0.10.9.0 mtl-2.2.2
haddock-interfaces:   /usr/share/doc/haskell-libxml/html/libxml.haddock
haddock-html:         /usr/share/doc/haskell-libxml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-libxml-0.1.1-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-libxml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 libxml
version:              0.1.1
visibility:           public
id:                   libxml-0.1.1-6Kr0y3wYUgdKImx5Xg3hwe
key:                  libxml-0.1.1-6Kr0y3wYUgdKImx5Xg3hwe
license:              BSD-3-Clause
copyright:            2006, Lemmih
maintainer:           Lemmih (lemmih@gmail.com)
author:               Lemmih (lemmih@gmail.com)
synopsis:             Binding to libxml2
description:
    Minimal binding to libxml2. Additional functions will be added when needed.

category:             XML
abi:                  7dc425aab8122dd8d11e083cc3c4026c
exposed:              True
exposed-modules:
    Text.XML.LibXML Text.XML.LibXML.Internals Text.XML.LibXML.Parser
    Text.XML.LibXML.Tree Text.XML.LibXML.Types

import-dirs:          /usr/lib/ghc-8.8.2/site-local/libxml-0.1.1
library-dirs:         /usr/lib/ghc-8.8.2/site-local/libxml-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.2/libxml-0.1.1
hs-libraries:         HSlibxml-0.1.1-6Kr0y3wYUgdKImx5Xg3hwe
extra-libraries:      xml2
include-dirs:         /usr/include/libxml2
includes:             libxml/xmlIO.h libxml/xmlmemory.h
depends:              base-4.13.0.0 bytestring-0.10.10.0 mtl-2.2.2
haddock-interfaces:   /usr/share/doc/haskell-libxml/html/libxml.haddock
haddock-html:         /usr/share/doc/haskell-libxml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
